# -*- coding: utf8 -*-
# ============LICENSE_START====================================================
# org.onap.vvp/validation-scripts
# ===================================================================
# Copyright © 2017 AT&T Intellectual Property. All rights reserved.
# ===================================================================
#
# Unless otherwise specified, all software contained herein is licensed
# under the Apache License, Version 2.0 (the "License");
# you may not use this software except in compliance with the License.
# You may obtain a copy of the License at
#
#             http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#
#
# Unless otherwise specified, all documentation contained herein is licensed
# under the Creative Commons License, Attribution 4.0 Intl. (the "License");
# you may not use this documentation except in compliance with the License.
# You may obtain a copy of the License at
#
#             https://creativecommons.org/licenses/by/4.0/
#
# Unless required by applicable law or agreed to in writing, documentation
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# ============LICENSE_END============================================
#
#

"""volume resources
"""

from os import path
from tests import cached_yaml as yaml

VERSION = "1.0.0"


def get_volume_resources(heat_template):
    """
    get the resources from the volume template
    Note: Returns an empty dict if there is no
    volume template or for any other error
    """
    basename = path.splitext(heat_template)[0]

    for ext in [".yaml", ".yml"]:
        volume_template = basename + "_volume" + ext
        if path.isfile(volume_template):
            break
    else:
        return {}

    try:
        with open(volume_template) as fh:
            yml = yaml.load(fh)
    except yaml.YAMLError as e:
        print(e)  # pylint: disable=superfluous-parens
        return {}

    if "outputs" not in yml:
        return {}
    if "resources" not in yml:
        return {}

    return yml["resources"]
